@@ -14,6 +14,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *  
  *  Copyright (C) 2000 - 2005 Petr Kubanek
+ *  Copyright (C) 2011 Petr Kubanek, Institute of Physics <kubanek@fzu.cz>
  */
 
 #include <math.h>
@@ -35,3 +36,13 @@ double ln_get_airmass (double alt, double airmass_scale)
   a = airmass_scale * sin (ln_deg_to_rad (alt));
   return sqrt (a * a + 2 * airmass_scale + 1) - a;
 }
+
+/*! \fn double ln_get_alt_from_airmass (double X, double airmass_scale)
+ * \param X              Airmass
+ * \param airmass_scale  Airmass scale - usually 750.
+ * \return  Altitude for give airmass.
+ */
+double ln_get_alt_from_airmass (double X, double airmass_scale)
+{
+	return ln_rad_to_deg (asin ((2 * airmass_scale + 1 - X * X) / (2 * X * airmass_scale)));
+}
