@@ -1,4 +1,4 @@
-/* $Id: utility.c 10415 2009-12-11 18:59:36Z smueller@cpan.org $
+/* $Id: utility.c,v 1.18 2009-04-20 07:17:00 pkubanek Exp $
  **
  * Copyright (C) 1999, 2000 Juan Carlos Remis
  * Copyright (C) 2002 Liam Girdwood
@@ -720,16 +720,6 @@ double cbrt (double x)
 
 #endif /* __C89_SUB__ */
 
-#ifndef HAVE_ROUND
-
-/* Simple round to nearest */
-double round (double x)
-{
-	return floor(x + 0.5);
-}
-
-#endif /* ! HAVE_ROUND */
-
 #if defined(__WIN32__) || defined(sun) || defined(__C89_SUB__)
 
 /* Not a Number function generator */
